@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
-our $DATE = '2015-09-29'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-30'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -26,18 +26,25 @@ sub firstidx (&@) {
     return -1;
 }
 
-sub __json {
-    state $json = do {
-        eval { require JSON::XS; 1 };
-        if ($@) {
-            require JSON::PP;
-            JSON::PP->new->canonical(1)->allow_nonref;
-        } else {
-            JSON::XS->new->canonical(1)->allow_nonref;
-        }
-    };
-    $json;
-}
+my $code_encode_json = do {
+    if    (eval { require JSON::XS; 1 })   { my $json = JSON::XS->new->canonical(1)->allow_nonref; sub { $json->encode(shift) } }
+    elsif (eval { require JSON::Tiny; 1 }) { \&JSON::Tiny::encode_json }
+    elsif (eval { require JSON::PP; 1 })   { my $json = JSON::PP->new->canonical(1)->allow_nonref; sub { $json->encode(shift) } }
+};
+
+my $code_encode_json_pretty = do {
+    if    (eval { require JSON::XS; 1 })   { my $json = JSON::XS->new->canonical(1)->allow_nonref->pretty; sub { $json->encode(shift) } }
+    elsif (eval { require JSON::Tiny; 1 }) { \&JSON::Tiny::encode_json }
+    elsif (eval { require JSON::PP; 1 })   { my $json = JSON::PP->new->canonical(1)->allow_nonref->pretty; sub { $json->encode(shift) } }
+    else { die "Can't find any JSON module" }
+};
+
+my $code_decode_json = do {
+    if    (eval { require JSON::XS; 1 })   { my $json = JSON::XS->new->canonical(1)->allow_nonref; sub { $json->decode(shift) } }
+    elsif (eval { require JSON::Tiny; 1 }) { \&JSON::Tiny::decode_json }
+    elsif (eval { require JSON::PP; 1 })   { my $json = JSON::PP->new->canonical(1)->allow_nonref; sub { $json->decode(shift) } }
+    else { die "Can't find any JSON module" }
+};
 
 sub __cleanse {
     state $cleanser = do {
@@ -74,7 +81,7 @@ sub __gen_table {
         # from env)
         my $tcos;
         if ($ENV{FORMAT_PRETTY_TABLE_COLUMN_ORDERS}) {
-            $tcos = __json->decode($ENV{FORMAT_PRETTY_TABLE_COLUMN_ORDERS});
+            $tcos = $code_decode_json->($ENV{FORMAT_PRETTY_TABLE_COLUMN_ORDERS});
         } elsif (my $rfos = ($resmeta->{'cmdline.format_options'} //
                                  $resmeta->{format_options})) {
             my $rfo = $rfos->{'text-pretty'} // $rfos->{text} // $rfos->{any};
@@ -191,9 +198,9 @@ sub format {
         unless $format =~ /\Ajson(-pretty)?\z/;
     __cleanse($res) if ($cleanse//1);
     if ($format eq 'json') {
-        return __json->encode($res) . "\n";
+        return $code_encode_json->($res) . "\n";
     } else {
-        return __json->canonical(1)->pretty->encode($res);
+        return $code_encode_json_pretty->($res);
     }
 }
 
@@ -212,7 +219,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.04 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2015-09-29.
+This document describes version 0.05 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2015-09-30.
 
 =head1 SYNOPSIS
 
